==> jikan_api-1.4.0.tar.gz: lib/jikan_api.dart <==
library jikan_api;

export 'src/jikan.dart';
export 'src/model/anime/anime.dart';
export 'src/model/anime/anime_item.dart';
export 'src/model/anime/character_staff.dart';
export 'src/model/anime/episode.dart';
export 'src/model/anime/promo.dart';
export 'src/model/anime/staff.dart';
export 'src/model/character/character.dart';
export 'src/model/character/character_role.dart';
export 'src/model/character/voice_actor.dart';
export 'src/model/club/club.dart';
export 'src/model/club/member.dart';
export 'src/model/common/aired.dart';
export 'src/model/common/article.dart';
export 'src/model/common/forum.dart';
export 'src/model/common/generic_info.dart';
export 'src/model/common/last_post.dart';
export 'src/model/common/meta.dart';
export 'src/model/common/more_info.dart';
export 'src/model/common/picture.dart';
export 'src/model/common/recommendation.dart';
export 'src/model/common/related.dart';
export 'src/model/common/review.dart';
export 'src/model/common/review_score.dart';
export 'src/model/common/reviewer.dart';
export 'src/model/common/score.dart';
export 'src/model/common/scores.dart';
export 'src/model/common/stats.dart';
export 'src/model/common/user_update.dart';
export 'src/model/constants.dart';
export 'src/model/genre/genre.dart';
export 'src/model/genre/genre_list.dart';
export 'src/model/genre/mal_url.dart';
export 'src/model/magazine/magazine.dart';
export 'src/model/manga/manga.dart';
export 'src/model/manga/manga_item.dart';
export 'src/model/person/anime_staff.dart';
export 'src/model/person/person.dart';
export 'src/model/person/published_manga.dart';
export 'src/model/person/voice_acting.dart';
export 'src/model/producer/producer.dart';
export 'src/model/schedule/schedule.dart';
export 'src/model/search/search.dart';
export 'src/model/season/season.dart';
export 'src/model/season/season_archive.dart';
export 'src/model/top/top.dart';
export 'src/model/user/favorite.dart';
export 'src/model/user/favorites.dart';
export 'src/model/user/friend.dart';
export 'src/model/user/history.dart';
export 'src/model/user/user_item.dart';
export 'src/model/user/user_profile.dart';
export 'src/model/user/user_stats.dart';

==> jikan_api-2.0.0.tar.gz: lib/jikan_api.dart <==
library jikan_api;

export 'package:built_collection/built_collection.dart' show BuiltList;
export 'src/jikan.dart';
export 'src/model/anime/anime.dart';
export 'src/model/anime/anime_meta.dart';
export 'src/model/anime/episode.dart';
export 'src/model/anime/promo.dart';
export 'src/model/character/character.dart';
export 'src/model/character/character_meta.dart';
export 'src/model/common/archive.dart';
export 'src/model/common/article.dart';
export 'src/model/common/entry_meta.dart';
export 'src/model/common/forum.dart';
export 'src/model/common/meta.dart';
export 'src/model/common/picture.dart';
export 'src/model/common/recommendation.dart';
export 'src/model/common/relation.dart';
export 'src/model/common/review.dart';
export 'src/model/common/score.dart';
export 'src/model/common/scores.dart';
export 'src/model/common/stats.dart';
export 'src/model/common/user_update.dart';
export 'src/model/constants.dart';
export 'src/model/genre/genre.dart';
export 'src/model/genre/genre_list.dart';
export 'src/model/magazine/magazine.dart';
export 'src/model/manga/manga.dart';
export 'src/model/manga/manga_meta.dart';
export 'src/model/person/person.dart';
export 'src/model/person/person_meta.dart';
export 'src/model/person/voice_actor.dart';
export 'src/model/producer/producer.dart';
export 'src/model/user/entry_update.dart';
export 'src/model/user/favorite.dart';
export 'src/model/user/favorites.dart';
export 'src/model/user/friend.dart';
export 'src/model/user/history.dart';
export 'src/model/user/user_meta.dart';
export 'src/model/user/user_profile.dart';
export 'src/model/user/user_recommendation.dart';
export 'src/model/user/user_review.dart';
export 'src/model/user/user_stats.dart';
export 'src/model/watch/watch_episode.dart';
export 'src/model/watch/watch_promo.dart';
